Overview — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

# Overview

“Help people read in their native language.”

Transifex is a modern, open-source localization platform. It’s a web system which automates the translation workflow of complex international projects.

Transifex helps projects work with an open community of translators to make their product available to a global audience. It helps software developers, documentation writers and webmasters globalize their products (or localize, depending on how one chooses to see the process) by openly receiving translations from a wide community via a dead-simple, batteries-included set of tools, which integrate well with existing workflows.

## Goals

Some of the core goals of Transifex are the following:

- Provide an interface for translators to submit translations to multiple projects, regardless of the type of the underlying VCS.
- Reduce the overhead a project maintainer usually undertakes to administrate accounts for translators.
- Help translators do more by eliminating the need to subscribe to each VCS and learn its commands and tricks.
- Encourage collaboration between developers and maintainers and thus, increase the language coverage of the participant projects.

## Transifex.net

Projects with a significant size, such as the Fedora or Moblin distributions, can benefit with a self-hosted Transifex instance. Most other projects though will probably want to use one which already has an established community and the necessary tools to help the project get translated.

Transifex.net is a one-stop, batteries-included service which serves translations to independent projects, which don’t have to worry about deploying their own instance, growing a community and managing the infrastructure. Tranisfex.net is managed by Indifex, the company sponsoring the development of Transifex itself.

## More information

Transifex is an open source product. Its source code is freely available. Planning, development and bug reporting takes place at the development site of http://transifex.org/.

Professional services such as 24/7 Support, Community Localization consulting and training are available by Indifex. For more information, please refer to the company’s website.